
## 📖 documentacao de mudanças em tempo real
## **documentacao de mudanças em tempo real** 
- **06/01/2024**  
  - Conceito: documentacao de mudanças em tempo real baseado em mudanças em um projeto selecionado
  - Podemos criar uma copia do projeto selecionado para o ambiente de trabalho do agente
  - enquanto isso observamos os arquivos do projeto a cada 60s 
  - se há alguma modificação em algum arquivo no ambiente de trabalho do usuario verificamos quais linhas foram alteradas e com base nisso criaremos ou adicionaremos no Improvmentslog no formato 01_01_2025 as mudanças feitas